tokenize_executable_file

Function tokenize_executable_file 

pub fn tokenize_executable_file<P>(executable: P) -> Result<Vec<Vec<u8>>>
where P: AsRef<Path>,
Naively tokenize an executable file by parsing its data sections. This very much assumes the executable isn’t behaving badly and that strings in it are actually in the data section.

For ELF executables, we take all non-executable and non-alloc sections.

For PE and COFF executables, we take the reserved sections .data and .rdata as noted in the docs.